# jQuery Themes Basics

This page demonstrates the very basics of the jQuery Themes plugin. It contains the minimum requirements for using the plugin and can be used as the basis for your own experimentation. For more detail see the documentation reference page.

The page shows a sample jQuery UI component and allows you to set the CSS theme to be used from amongst the jQuery ThemeRoller examples.

Select your new theme:

jQuery UI sample

## Datepicker

Prev Next
December 2008

Su | Mo | Tu | We | Th | Fr | Sa
--- | --- | --- | --- | --- | --- | ---
| 1 | 2 | 3 | 4 | 5 | 6
7 | 8 | 9 | 10 | 11 | 12 | 13
14 | 15 | 16 | 17 | 18 | 19 | 20
21 | 22 | 23 | 24 | 25 | 26 | 27
28 | 29 | 30 | 31 |  |  |